Class: PulpAnsibleClient::AnsibleCollectionRemoteResponse
- Inherits:
-
Object
- Object
- PulpAnsibleClient::AnsibleCollectionRemoteResponse
- Defined in:
- lib/pulp_ansible_client/models/ansible_collection_remote_response.rb
Overview
A serializer for Collection Remotes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auth_url ⇒ Object
The URL to receive a session token from, e.g.
-
#ca_cert ⇒ Object
A PEM encoded CA certificate used to validate the server certificate presented by the remote server.
-
#client_cert ⇒ Object
A PEM encoded client certificate used for authentication.
-
#connect_timeout ⇒ Object
aiohttp.ClientTimeout.connect (q.v.) for download-connections.
-
#download_concurrency ⇒ Object
Total number of simultaneous connections.
-
#headers ⇒ Object
Headers for aiohttp.Clientsession.
-
#hidden_fields ⇒ Object
List of hidden (write only) fields.
-
#last_sync_task ⇒ Object
Returns the value of attribute last_sync_task.
-
#max_retries ⇒ Object
Maximum number of retry attempts after a download failure.
-
#name ⇒ Object
A unique name for this remote.
-
#policy ⇒ Object
The policy to use when downloading content.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#proxy_url ⇒ Object
The proxy URL.
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#pulp_last_updated ⇒ Object
Timestamp of the most recent update of the remote.
-
#rate_limit ⇒ Object
Limits requests per second for each concurrent downloader.
-
#requirements_file ⇒ Object
The string version of Collection requirements yaml.
-
#signed_only ⇒ Object
Sync only collections that have a signature.
-
#sock_connect_timeout ⇒ Object
aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections.
-
#sock_read_timeout ⇒ Object
aiohttp.ClientTimeout.sock_read (q.v.) for download-connections.
-
#sync_dependencies ⇒ Object
Sync dependencies for collections specified via requirements file.
-
#sync_highest_versions ⇒ Object
The number of highest versions of each collection to sync.
-
#tls_validation ⇒ Object
If True, TLS peer validation must be performed.
-
#total_timeout ⇒ Object
aiohttp.ClientTimeout.total (q.v.) for download-connections.
-
#url ⇒ Object
The URL of an external content source.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnsibleCollectionRemoteResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AnsibleCollectionRemoteResponse
Initializes the object
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 211 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpAnsibleClient::AnsibleCollectionRemoteResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpAnsibleClient::AnsibleCollectionRemoteResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'policy') self.policy = attributes[:'policy'] end if attributes.key?(:'hidden_fields') if (value = attributes[:'hidden_fields']).is_a?(Array) self.hidden_fields = value end end if attributes.key?(:'ca_cert') self.ca_cert = attributes[:'ca_cert'] end if attributes.key?(:'client_cert') self.client_cert = attributes[:'client_cert'] end if attributes.key?(:'tls_validation') self.tls_validation = attributes[:'tls_validation'] end if attributes.key?(:'proxy_url') self.proxy_url = attributes[:'proxy_url'] end if attributes.key?(:'max_retries') self.max_retries = attributes[:'max_retries'] end if attributes.key?(:'total_timeout') self.total_timeout = attributes[:'total_timeout'] end if attributes.key?(:'connect_timeout') self.connect_timeout = attributes[:'connect_timeout'] end if attributes.key?(:'sock_connect_timeout') self.sock_connect_timeout = attributes[:'sock_connect_timeout'] end if attributes.key?(:'sock_read_timeout') self.sock_read_timeout = attributes[:'sock_read_timeout'] end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Array) self.headers = value end end if attributes.key?(:'download_concurrency') self.download_concurrency = attributes[:'download_concurrency'] end if attributes.key?(:'rate_limit') self.rate_limit = attributes[:'rate_limit'] end if attributes.key?(:'requirements_file') self.requirements_file = attributes[:'requirements_file'] end if attributes.key?(:'auth_url') self.auth_url = attributes[:'auth_url'] end if attributes.key?(:'sync_dependencies') self.sync_dependencies = attributes[:'sync_dependencies'] end if attributes.key?(:'signed_only') self.signed_only = attributes[:'signed_only'] end if attributes.key?(:'sync_highest_versions') self.sync_highest_versions = attributes[:'sync_highest_versions'] end if attributes.key?(:'last_sync_task') self.last_sync_task = attributes[:'last_sync_task'] end end |
Instance Attribute Details
#auth_url ⇒ Object
The URL to receive a session token from, e.g. used with Automation Hub.
84 85 86 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 84 def auth_url @auth_url end |
#ca_cert ⇒ Object
A PEM encoded CA certificate used to validate the server certificate presented by the remote server.
45 46 47 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 45 def ca_cert @ca_cert end |
#client_cert ⇒ Object
A PEM encoded client certificate used for authentication.
48 49 50 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 48 def client_cert @client_cert end |
#connect_timeout ⇒ Object
aiohttp.ClientTimeout.connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.
63 64 65 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 63 def connect_timeout @connect_timeout end |
#download_concurrency ⇒ Object
Total number of simultaneous connections. If not set then the default value will be used.
75 76 77 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 75 def download_concurrency @download_concurrency end |
#headers ⇒ Object
Headers for aiohttp.Clientsession
72 73 74 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 72 def headers @headers end |
#hidden_fields ⇒ Object
List of hidden (write only) fields
42 43 44 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 42 def hidden_fields @hidden_fields end |
#last_sync_task ⇒ Object
Returns the value of attribute last_sync_task.
95 96 97 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 95 def last_sync_task @last_sync_task end |
#max_retries ⇒ Object
Maximum number of retry attempts after a download failure. If not set then the default value (3) will be used.
57 58 59 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 57 def max_retries @max_retries end |
#name ⇒ Object
A unique name for this remote.
31 32 33 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 31 def name @name end |
#policy ⇒ Object
The policy to use when downloading content. * immediate - When syncing, download all metadata and content now.
39 40 41 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 39 def policy @policy end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 22 def prn @prn end |
#proxy_url ⇒ Object
The proxy URL. Format: scheme://host:port
54 55 56 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 54 def proxy_url @proxy_url end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
36 37 38 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 36 def pulp_labels @pulp_labels end |
#pulp_last_updated ⇒ Object
Timestamp of the most recent update of the remote.
28 29 30 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#rate_limit ⇒ Object
Limits requests per second for each concurrent downloader
78 79 80 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 78 def rate_limit @rate_limit end |
#requirements_file ⇒ Object
The string version of Collection requirements yaml.
81 82 83 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 81 def requirements_file @requirements_file end |
#signed_only ⇒ Object
Sync only collections that have a signature
90 91 92 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 90 def signed_only @signed_only end |
#sock_connect_timeout ⇒ Object
aiohttp.ClientTimeout.sock_connect (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.
66 67 68 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 66 def sock_connect_timeout @sock_connect_timeout end |
#sock_read_timeout ⇒ Object
aiohttp.ClientTimeout.sock_read (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.
69 70 71 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 69 def sock_read_timeout @sock_read_timeout end |
#sync_dependencies ⇒ Object
Sync dependencies for collections specified via requirements file
87 88 89 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 87 def sync_dependencies @sync_dependencies end |
#sync_highest_versions ⇒ Object
The number of highest versions of each collection to sync. Unset or null syncs all versions. 1 syncs only the highest version.
93 94 95 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 93 def sync_highest_versions @sync_highest_versions end |
#tls_validation ⇒ Object
If True, TLS peer validation must be performed.
51 52 53 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 51 def tls_validation @tls_validation end |
#total_timeout ⇒ Object
aiohttp.ClientTimeout.total (q.v.) for download-connections. The default is null, which will cause the default from the aiohttp library to be used.
60 61 62 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 60 def total_timeout @total_timeout end |
#url ⇒ Object
The URL of an external content source.
34 35 36 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 34 def url @url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 546 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpAnsibleClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
153 154 155 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 153 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 120 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'name' => :'name', :'url' => :'url', :'pulp_labels' => :'pulp_labels', :'policy' => :'policy', :'hidden_fields' => :'hidden_fields', :'ca_cert' => :'ca_cert', :'client_cert' => :'client_cert', :'tls_validation' => :'tls_validation', :'proxy_url' => :'proxy_url', :'max_retries' => :'max_retries', :'total_timeout' => :'total_timeout', :'connect_timeout' => :'connect_timeout', :'sock_connect_timeout' => :'sock_connect_timeout', :'sock_read_timeout' => :'sock_read_timeout', :'headers' => :'headers', :'download_concurrency' => :'download_concurrency', :'rate_limit' => :'rate_limit', :'requirements_file' => :'requirements_file', :'auth_url' => :'auth_url', :'sync_dependencies' => :'sync_dependencies', :'signed_only' => :'signed_only', :'sync_highest_versions' => :'sync_highest_versions', :'last_sync_task' => :'last_sync_task' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 522 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 191 def self.openapi_nullable Set.new([ :'ca_cert', :'client_cert', :'proxy_url', :'max_retries', :'total_timeout', :'connect_timeout', :'sock_connect_timeout', :'sock_read_timeout', :'download_concurrency', :'rate_limit', :'requirements_file', :'auth_url', :'sync_highest_versions', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 158 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'name' => :'String', :'url' => :'String', :'pulp_labels' => :'Hash<String, String>', :'policy' => :'PolicyEnum', :'hidden_fields' => :'Array<AnsibleCollectionRemoteResponseHiddenFieldsInner>', :'ca_cert' => :'String', :'client_cert' => :'String', :'tls_validation' => :'Boolean', :'proxy_url' => :'String', :'max_retries' => :'Integer', :'total_timeout' => :'Float', :'connect_timeout' => :'Float', :'sock_connect_timeout' => :'Float', :'sock_read_timeout' => :'Float', :'headers' => :'Array<Object>', :'download_concurrency' => :'Integer', :'rate_limit' => :'Integer', :'requirements_file' => :'String', :'auth_url' => :'String', :'sync_dependencies' => :'Boolean', :'signed_only' => :'Boolean', :'sync_highest_versions' => :'Integer', :'last_sync_task' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 475 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && name == o.name && url == o.url && pulp_labels == o.pulp_labels && policy == o.policy && hidden_fields == o.hidden_fields && ca_cert == o.ca_cert && client_cert == o.client_cert && tls_validation == o.tls_validation && proxy_url == o.proxy_url && max_retries == o.max_retries && total_timeout == o.total_timeout && connect_timeout == o.connect_timeout && sock_connect_timeout == o.sock_connect_timeout && sock_read_timeout == o.sock_read_timeout && headers == o.headers && download_concurrency == o.download_concurrency && rate_limit == o.rate_limit && requirements_file == o.requirements_file && auth_url == o.auth_url && sync_dependencies == o.sync_dependencies && signed_only == o.signed_only && sync_highest_versions == o.sync_highest_versions && last_sync_task == o.last_sync_task end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 617 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
509 510 511 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 509 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
515 516 517 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 515 def hash [pulp_href, prn, pulp_created, pulp_last_updated, name, url, pulp_labels, policy, hidden_fields, ca_cert, client_cert, tls_validation, proxy_url, max_retries, total_timeout, connect_timeout, sock_connect_timeout, sock_read_timeout, headers, download_concurrency, rate_limit, requirements_file, auth_url, sync_dependencies, signed_only, sync_highest_versions, last_sync_task].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 345 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if !@total_timeout.nil? && @total_timeout < 0.0 invalid_properties.push('invalid value for "total_timeout", must be greater than or equal to 0.0.') end if !@connect_timeout.nil? && @connect_timeout < 0.0 invalid_properties.push('invalid value for "connect_timeout", must be greater than or equal to 0.0.') end if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0 invalid_properties.push('invalid value for "sock_connect_timeout", must be greater than or equal to 0.0.') end if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0 invalid_properties.push('invalid value for "sock_read_timeout", must be greater than or equal to 0.0.') end if !@download_concurrency.nil? && @download_concurrency < 1 invalid_properties.push('invalid value for "download_concurrency", must be greater than or equal to 1.') end if !@auth_url.nil? && @auth_url.to_s.length > 255 invalid_properties.push('invalid value for "auth_url", the character length must be smaller than or equal to 255.') end if !@sync_highest_versions.nil? && @sync_highest_versions < 1 invalid_properties.push('invalid value for "sync_highest_versions", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
593 594 595 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 593 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 599 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
587 588 589 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 587 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/pulp_ansible_client/models/ansible_collection_remote_response.rb', line 389 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @url.nil? return false if !@total_timeout.nil? && @total_timeout < 0.0 return false if !@connect_timeout.nil? && @connect_timeout < 0.0 return false if !@sock_connect_timeout.nil? && @sock_connect_timeout < 0.0 return false if !@sock_read_timeout.nil? && @sock_read_timeout < 0.0 return false if !@download_concurrency.nil? && @download_concurrency < 1 return false if !@auth_url.nil? && @auth_url.to_s.length > 255 return false if !@sync_highest_versions.nil? && @sync_highest_versions < 1 true end |