Class: PulpAnsibleClient::AnsibleCollectionVersionResponse
- Inherits:
-
Object
- Object
- PulpAnsibleClient::AnsibleCollectionVersionResponse
- Defined in:
- lib/pulp_ansible_client/models/ansible_collection_version_response.rb
Overview
A serializer for CollectionVersion Content.
Instance Attribute Summary collapse
-
#artifact ⇒ Object
Artifact file representing the physical content.
-
#authors ⇒ Object
A list of the CollectionVersion content’s authors.
-
#dependencies ⇒ Object
A dict declaring Collections that this collection requires to be installed for it to be usable.
-
#description ⇒ Object
A short summary description of the collection.
-
#documentation ⇒ Object
The URL to any online docs.
-
#homepage ⇒ Object
The URL to the homepage of the collection/project.
-
#id ⇒ Object
A collection identifier.
-
#issues ⇒ Object
The URL to the collection issue tracker.
-
#license ⇒ Object
A list of licenses for content inside of a collection.
-
#md5 ⇒ Object
The MD5 checksum if available.
-
#name ⇒ Object
The name of the collection.
-
#namespace ⇒ Object
The namespace of the collection.
-
#origin_repository ⇒ Object
The URL of the originating SCM repository.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#requires_ansible ⇒ Object
The version of Ansible required to use the collection.
-
#sha1 ⇒ Object
The SHA-1 checksum if available.
-
#sha224 ⇒ Object
The SHA-224 checksum if available.
-
#sha256 ⇒ Object
The SHA-256 checksum if available.
-
#sha384 ⇒ Object
The SHA-384 checksum if available.
-
#sha512 ⇒ Object
The SHA-512 checksum if available.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#version ⇒ Object
The version of the collection.
-
#vuln_report ⇒ Object
Returns the value of attribute vuln_report.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnsibleCollectionVersionResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AnsibleCollectionVersionResponse
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 177 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpAnsibleClient::AnsibleCollectionVersionResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpAnsibleClient::AnsibleCollectionVersionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'vuln_report') self.vuln_report = attributes[:'vuln_report'] end if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'artifact') self.artifact = attributes[:'artifact'] end if attributes.key?(:'sha256') self.sha256 = attributes[:'sha256'] end if attributes.key?(:'md5') self.md5 = attributes[:'md5'] end if attributes.key?(:'sha1') self.sha1 = attributes[:'sha1'] end if attributes.key?(:'sha224') self.sha224 = attributes[:'sha224'] end if attributes.key?(:'sha384') self.sha384 = attributes[:'sha384'] end if attributes.key?(:'sha512') self.sha512 = attributes[:'sha512'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'authors') if (value = attributes[:'authors']).is_a?(Array) self. = value end end if attributes.key?(:'dependencies') self.dependencies = attributes[:'dependencies'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'documentation') self.documentation = attributes[:'documentation'] end if attributes.key?(:'homepage') self.homepage = attributes[:'homepage'] end if attributes.key?(:'issues') self.issues = attributes[:'issues'] end if attributes.key?(:'license') if (value = attributes[:'license']).is_a?(Array) self.license = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'namespace') self.namespace = attributes[:'namespace'] end if attributes.key?(:'origin_repository') self.origin_repository = attributes[:'origin_repository'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'requires_ansible') self.requires_ansible = attributes[:'requires_ansible'] end end |
Instance Attribute Details
#artifact ⇒ Object
Artifact file representing the physical content
36 37 38 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 36 def artifact @artifact end |
#authors ⇒ Object
A list of the CollectionVersion content’s authors.
60 61 62 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 60 def @authors end |
#dependencies ⇒ Object
A dict declaring Collections that this collection requires to be installed for it to be usable.
63 64 65 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 63 def dependencies @dependencies end |
#description ⇒ Object
A short summary description of the collection.
66 67 68 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 66 def description @description end |
#documentation ⇒ Object
The URL to any online docs.
69 70 71 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 69 def documentation @documentation end |
#homepage ⇒ Object
The URL to the homepage of the collection/project.
72 73 74 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 72 def homepage @homepage end |
#id ⇒ Object
A collection identifier.
57 58 59 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 57 def id @id end |
#issues ⇒ Object
The URL to the collection issue tracker.
75 76 77 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 75 def issues @issues end |
#license ⇒ Object
A list of licenses for content inside of a collection.
78 79 80 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 78 def license @license end |
#md5 ⇒ Object
The MD5 checksum if available.
42 43 44 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 42 def md5 @md5 end |
#name ⇒ Object
The name of the collection.
81 82 83 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 81 def name @name end |
#namespace ⇒ Object
The namespace of the collection.
84 85 86 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 84 def namespace @namespace end |
#origin_repository ⇒ Object
The URL of the originating SCM repository.
87 88 89 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 87 def origin_repository @origin_repository end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
20 21 22 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 20 def prn @prn end |
#pulp_created ⇒ Object
Timestamp of creation.
23 24 25 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 23 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
33 34 35 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 33 def pulp_href @pulp_href end |
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
29 30 31 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 29 def pulp_labels @pulp_labels end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
26 27 28 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 26 def pulp_last_updated @pulp_last_updated end |
#requires_ansible ⇒ Object
The version of Ansible required to use the collection. Multiple versions can be separated with a comma.
95 96 97 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 95 def requires_ansible @requires_ansible end |
#sha1 ⇒ Object
The SHA-1 checksum if available.
45 46 47 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 45 def sha1 @sha1 end |
#sha224 ⇒ Object
The SHA-224 checksum if available.
48 49 50 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 48 def sha224 @sha224 end |
#sha256 ⇒ Object
The SHA-256 checksum if available.
39 40 41 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 39 def sha256 @sha256 end |
#sha384 ⇒ Object
The SHA-384 checksum if available.
51 52 53 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 51 def sha384 @sha384 end |
#sha512 ⇒ Object
The SHA-512 checksum if available.
54 55 56 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 54 def sha512 @sha512 end |
#tags ⇒ Object
Returns the value of attribute tags.
89 90 91 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 89 def @tags end |
#version ⇒ Object
The version of the collection.
92 93 94 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 92 def version @version end |
#vuln_report ⇒ Object
Returns the value of attribute vuln_report.
31 32 33 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 31 def vuln_report @vuln_report end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 543 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpAnsibleClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
131 132 133 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 131 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 98 def self.attribute_map { :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'pulp_labels' => :'pulp_labels', :'vuln_report' => :'vuln_report', :'pulp_href' => :'pulp_href', :'artifact' => :'artifact', :'sha256' => :'sha256', :'md5' => :'md5', :'sha1' => :'sha1', :'sha224' => :'sha224', :'sha384' => :'sha384', :'sha512' => :'sha512', :'id' => :'id', :'authors' => :'authors', :'dependencies' => :'dependencies', :'description' => :'description', :'documentation' => :'documentation', :'homepage' => :'homepage', :'issues' => :'issues', :'license' => :'license', :'name' => :'name', :'namespace' => :'namespace', :'origin_repository' => :'origin_repository', :'tags' => :'tags', :'version' => :'version', :'requires_ansible' => :'requires_ansible' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 519 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
169 170 171 172 173 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 169 def self.openapi_nullable Set.new([ :'requires_ansible' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 136 def self.openapi_types { :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'pulp_labels' => :'Hash<String, String>', :'vuln_report' => :'String', :'pulp_href' => :'String', :'artifact' => :'String', :'sha256' => :'String', :'md5' => :'String', :'sha1' => :'String', :'sha224' => :'String', :'sha384' => :'String', :'sha512' => :'String', :'id' => :'String', :'authors' => :'Array<String>', :'dependencies' => :'Object', :'description' => :'String', :'documentation' => :'String', :'homepage' => :'String', :'issues' => :'String', :'license' => :'Array<String>', :'name' => :'String', :'namespace' => :'String', :'origin_repository' => :'String', :'tags' => :'Array<CollectionSummaryResponseTagsInner>', :'version' => :'String', :'requires_ansible' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 472 def ==(o) return true if self.equal?(o) self.class == o.class && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && pulp_labels == o.pulp_labels && vuln_report == o.vuln_report && pulp_href == o.pulp_href && artifact == o.artifact && sha256 == o.sha256 && md5 == o.md5 && sha1 == o.sha1 && sha224 == o.sha224 && sha384 == o.sha384 && sha512 == o.sha512 && id == o.id && == o. && dependencies == o.dependencies && description == o.description && documentation == o.documentation && homepage == o.homepage && issues == o.issues && license == o.license && name == o.name && namespace == o.namespace && origin_repository == o.origin_repository && == o. && version == o.version && requires_ansible == o.requires_ansible end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 614 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
506 507 508 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 506 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
512 513 514 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 512 def hash [prn, pulp_created, pulp_last_updated, pulp_labels, vuln_report, pulp_href, artifact, sha256, md5, sha1, sha224, sha384, sha512, id, , dependencies, description, documentation, homepage, issues, license, name, namespace, origin_repository, , version, requires_ansible].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 309 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@documentation.nil? && @documentation.to_s.length > 2000 invalid_properties.push('invalid value for "documentation", the character length must be smaller than or equal to 2000.') end if !@homepage.nil? && @homepage.to_s.length > 2000 invalid_properties.push('invalid value for "homepage", the character length must be smaller than or equal to 2000.') end if !@issues.nil? && @issues.to_s.length > 2000 invalid_properties.push('invalid value for "issues", the character length must be smaller than or equal to 2000.') end if !@name.nil? && @name.to_s.length > 64 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 64.') end if !@namespace.nil? && @namespace.to_s.length > 64 invalid_properties.push('invalid value for "namespace", the character length must be smaller than or equal to 64.') end if !@origin_repository.nil? && @origin_repository.to_s.length > 2000 invalid_properties.push('invalid value for "origin_repository", the character length must be smaller than or equal to 2000.') end if !@version.nil? && @version.to_s.length > 128 invalid_properties.push('invalid value for "version", the character length must be smaller than or equal to 128.') end if !@requires_ansible.nil? && @requires_ansible.to_s.length > 255 invalid_properties.push('invalid value for "requires_ansible", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
590 591 592 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 590 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 596 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
584 585 586 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 584 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/pulp_ansible_client/models/ansible_collection_version_response.rb', line 349 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@documentation.nil? && @documentation.to_s.length > 2000 return false if !@homepage.nil? && @homepage.to_s.length > 2000 return false if !@issues.nil? && @issues.to_s.length > 2000 return false if !@name.nil? && @name.to_s.length > 64 return false if !@namespace.nil? && @namespace.to_s.length > 64 return false if !@origin_repository.nil? && @origin_repository.to_s.length > 2000 return false if !@version.nil? && @version.to_s.length > 128 return false if !@requires_ansible.nil? && @requires_ansible.to_s.length > 255 true end |